# Papers
For more information on the different algorithms and implementations in PLANC please refer to the following papers.  
* Srinivas Eswar, Benjamin Cobb, Koby Hayashi, Ramakrishnan Kannan, Grey Ballard, Richard Vuduc, and Haesun Park. 2023. Distributed-Memory Parallel JointNMF. In Proceedings of the 37th International Conference on Supercomputing (ICS '23). Association for Computing Machinery, New York, NY, USA, 301–312. [[doi]](https://doi.org/10.1145/3577193.3593733)
* Srinivas Eswar. "Scalable Data Mining via Constrained Low Rank Approximation." (Doctoral Disseration) (2022). [[link]](http://hdl.handle.net/1853/67334)
* Srinivas Eswar, Koby Hayashi, Grey Ballard, Ramakrishnan Kannan, Michael A. Matheson, and Haesun Park. 2021. PLANC: Parallel Low-rank Approximation with Nonnegativity Constraints. ACM Trans. Math. Softw. 47, 3, Article 20 (September 2021), 37 pages. [[doi]](https://doi.org/10.1145/3432185)
*  Lawton Manning, Grey Ballard, Ramakrishnan Kannan, and Haesun Park, "Parallel Hierarchical Clustering using Rank-Two Nonnegative Matrix Factorization," 2020 IEEE 27th International Conference on High Performance Computing, Data, and Analytics (HiPC), Pune, India, 2020, pp. 141-150. [[doi]](https://doi.org/10.1109/HiPC50609.2020.00028)
* Srinivas Eswar, Koby Hayashi, Grey Ballard, Ramakrishnan Kannan, Richard Vuduc, and Haesun Park, "Distributed-Memory Parallel Symmetric Nonnegative Matrix Factorization," SC20: International Conference for High Performance Computing, Networking, Storage and Analysis, Atlanta, GA, USA, 2020, pp. 1-14. [[doi]](https://doi.org/10.1109/SC41405.2020.00078)
* Grey Ballard, Koby Hayashi and Ramakrishnan Kannan, "Parallel Nonnegative CP Decomposition of Dense Tensors," 2018 IEEE 25th International Conference on High Performance Computing (HiPC), Bengaluru, India, 2018, pp. 22-31. [[doi]](https://doi.org/10.1109/HiPC.2018.00012)
* Oguz Kaya, Ramakrishnan Kannan, and Grey Ballard. 2018. Partitioning and Communication Strategies for Sparse Non-negative Matrix Factorization. In Proceedings of the 47th International Conference on Parallel Processing (ICPP '18). Association for Computing Machinery, New York, NY, USA, Article 90, 1–10. [[doi]](https://doi.org/10.1145/3225058.3225127)
* Ramakrishnan Kannan, Grey Ballard and Haesun Park, "MPI-FAUN: An MPI-Based Framework for Alternating-Updating Nonnegative Matrix Factorization," in IEEE Transactions on Knowledge and Data Engineering, vol. 30, no. 3, pp. 544-558, 1 March 2018. [[doi]](https://doi.org/10.1109/TKDE.2017.2767592)
* Ramakrishnan Kannan, Grey Ballard, and Haesun Park. 2016. A high-performance parallel algorithm for nonnegative matrix factorization. In Proceedings of the 21st ACM SIGPLAN Symposium on Principles and Practice of Parallel Programming (PPoPP '16). Association for Computing Machinery, New York, NY, USA, Article 9, 1–11. [[doi]](https://doi.org/10.1145/2851141.2851152)
* Ramakrishnan Kannan. "Scalable and Distributed Constrained Low Rank Approximations." (Doctoral Disseration) (2016). [[link]](http://hdl.handle.net/1853/54962)